"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _path = _interopRequireDefault(require("path"));
var _properLockfile = _interopRequireDefault(require("proper-lockfile"));
var _fs = require("fs");
function _classPrivateMethodInitSpec(e, a) { _checkPrivateRedeclaration(e, a), a.add(e); }
function _checkPrivateRedeclaration(e, t) { if (t.has(e)) throw new TypeError("Cannot initialize the same private elements twice on an object"); }
function _assertClassBrand(e, t, n) { if ("function" == typeof e ? e === t : e.has(t)) return arguments.length < 3 ? t : n; throw new TypeError("Private element is not present on this object"); }
var _FileMutex_brand = /*#__PURE__*/new WeakSet();
class FileMutex {
  constructor(directory, lockFileName, options = {}) {
    _classPrivateMethodInitSpec(this, _FileMutex_brand);
    this.directory = directory;
    this.lockFileName = lockFileName + ".lock";
    this.options = options;
  }
  async acquire() {
    _assertClassBrand(_FileMutex_brand, this, _createDirectoryIfNotExist).call(this);
    const lockFilePath = _assertClassBrand(_FileMutex_brand, this, _getLockFilePath).call(this);
    try {
      if (!(0, _fs.existsSync)(lockFilePath)) {
        console.log(`[DEBUG] Creating missing lock file:`, this.lockFileName);
        (0, _fs.writeFileSync)(lockFilePath, 'locked');
      }
      await _properLockfile.default.lock(lockFilePath, this.options);
    } catch (err) {
      throw new Error(`Failed to acquire lock after ${this.options.retries.retries} attempts: ${err.message}`);
    }
  }
  async release() {
    try {
      await _properLockfile.default.unlock(_assertClassBrand(_FileMutex_brand, this, _getLockFilePath).call(this));
    } catch (err) {
      throw new Error(`Failed to release lock: ${err.message}`);
    }
  }
}
function _getLockFilePath() {
  return _path.default.resolve(_path.default.join(this.directory, this.lockFileName));
}
function _createDirectoryIfNotExist() {
  if (!(0, _fs.existsSync)(this.directory)) {
    (0, _fs.mkdirSync)(this.directory, {
      recursive: true
    });
  }
}
var _default = exports.default = FileMutex;