"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
var _fileMutex = _interopRequireDefault(require("../../../../../core/playwright/helpers/fileMutex"));
var _properLockfile = _interopRequireDefault(require("proper-lockfile"));
var _path = _interopRequireDefault(require("path"));
var _fs = _interopRequireDefault(require("fs"));
jest.mock('proper-lockfile');
jest.mock('fs');
describe('FileMutex', () => {
  const directory = '/tmp/locks';
  const lockFileName = 'test-lock';
  const options = {
    stale: 10000,
    retries: {
      retries: 5,
      factor: 1,
      minTimeout: 5000,
      maxTimeout: 8000
    }
  };
  const lockFilePath = _path.default.resolve(directory, lockFileName + '.lock');
  let fileMutex;
  beforeEach(() => {
    fileMutex = new _fileMutex.default(directory, lockFileName, options);
    jest.clearAllMocks();
  });
  describe('acquire', () => {
    it('should create the directory if it does not exist', async () => {
      _fs.default.existsSync.mockReturnValue(false);
      _fs.default.mkdirSync.mockImplementation(() => {});
      _properLockfile.default.lock.mockResolvedValue();
      await fileMutex.acquire();
      expect(_fs.default.existsSync).toHaveBeenCalledWith(directory);
      expect(_fs.default.mkdirSync).toHaveBeenCalledWith(directory, {
        recursive: true
      });
    });
    it('should create the lock file if it does not exist', async () => {
      _fs.default.existsSync.mockImplementation(filePath => filePath !== lockFilePath);
      _fs.default.writeFileSync.mockImplementation(() => {});
      _properLockfile.default.lock.mockResolvedValue();
      await fileMutex.acquire();
      expect(_fs.default.existsSync).toHaveBeenCalledWith(lockFilePath);
      expect(_fs.default.writeFileSync).toHaveBeenCalledWith(lockFilePath, 'locked');
    });
    it('should acquire the lock using proper-lockfile', async () => {
      _fs.default.existsSync.mockReturnValue(true);
      _properLockfile.default.lock.mockResolvedValue();
      await fileMutex.acquire();
      expect(_properLockfile.default.lock).toHaveBeenCalledWith(lockFilePath, options);
    });
    it('should throw an error if lock acquisition fails', async () => {
      const errorMessage = 'Lock acquisition failed';
      _properLockfile.default.lock.mockRejectedValue(new Error(errorMessage));
      await expect(fileMutex.acquire()).rejects.toThrow(`Failed to acquire lock after ${options.retries.retries} attempts: ${errorMessage}`);
    });
  });
  describe('release', () => {
    it('should release the lock using proper-lockfile', async () => {
      _properLockfile.default.unlock.mockResolvedValue();
      await fileMutex.release();
      expect(_properLockfile.default.unlock).toHaveBeenCalledWith(lockFilePath);
    });
    it('should throw an error if lock release fails', async () => {
      const errorMessage = 'Lock release failed';
      _properLockfile.default.unlock.mockRejectedValue(new Error(errorMessage));
      await expect(fileMutex.release()).rejects.toThrow(`Failed to release lock: ${errorMessage}`);
    });
  });
});